@@ -342,8 +342,8 @@ class ScramblerGUI:
 		print('Timetravel will alter the metadata to a scrambled date/time in the past of everything in:')
 		print(self.instance.wd)
 		print(' ')
-		print('You may specify a file type to timetravel. Leave blank for default .txt files.')
-		print('Use * to timetravel all files regardless of type (this can be dangerous).')
+		print('You may specify a file type. Leaving blank will default to .txt files.')
+		print('Use * for all files regardless of type (this can be dangerous).')
 		print(' ')
 		raw_extension = input('Specify a file type [Optional]: ')
 		extension = FileModder.format_ext(raw_extension, ifblank='.txt')
